@@ -279,42 +279,55 @@ def is_datetime_in_datetime_range(check_datetime: datetime, datetime_range: (dat
     return is_datetime_in_datetime_range_result
 
 
-def get_brand_name() -> str:
-    get_brand_name_result = our_get_env("BRAND_NAME")
+def get_brand_name(raise_if_not_found: bool = True,
+                   raise_if_empty: bool = False) -> str:
+    get_brand_name_result = our_get_env("BRAND_NAME",
+                                        raise_if_not_found=raise_if_not_found,
+                                        raise_if_empty=raise_if_empty)
     return get_brand_name_result
 
 
-def get_environment_name() -> str:
-    environment_name = our_get_env("ENVIRONMENT_NAME")
+def get_environment_name(raise_if_not_found: bool = True,
+                         raise_if_empty: bool = False) -> str:
+    environment_name = our_get_env("ENVIRONMENT_NAME",
+                                   raise_if_not_found=raise_if_not_found,
+                                   raise_if_empty=raise_if_empty)
     EnvironmentName(environment_name)  # if invalid, raises ValueError: x is not a valid EnvironmentName
     return environment_name
 
 
+# TODO add optional_prefix optional parameter. First check with optional_prefix, if not found, check without it.
 def our_get_env(key: str, default: str = None, raise_if_not_found: bool = True,
                 raise_if_empty: bool = False) -> str:
-    logger.start(object={"key": key, "default": default, "raise_if_not_found": raise_if_not_found,
+    logger.start(object={"key": key, "default": default,
+                         "raise_if_not_found": raise_if_not_found,
                          "raise_if_empty": raise_if_empty})
     env_var = os.getenv(key, default)
+    # TODO: "default is None" is always False
     if ((raise_if_not_found and key not in os.environ and default is None)
             or (raise_if_empty and not env_var and not default)):
-        raise Exception(f"Environment variable {key} not found - please check your .env file")
+        raise Exception(f"Environment variable {key} not found - please check your .env file")  # noqa: E501
     logger.end(object={"env_var": env_var})
     return env_var
 
 
-# TODO As only the database package uses those, let's move those three to the database package
-def get_sql_hostname() -> str:
-    get_sql_hostname_result = our_get_env("RDS_HOSTNAME")
+# TODO As only the database package uses those, let's move those three to the database package  # noqa: E501
+def get_sql_hostname(raise_if_not_found: bool = True,
+                     raise_if_empty: bool = False) -> str:
+    get_sql_hostname_result = our_get_env("RDS_HOSTNAME",
+                                          raise_if_empty=raise_if_empty)
     return get_sql_hostname_result
 
 
-def get_sql_username() -> str:
-    get_sql_username_result = our_get_env("RDS_USERNAME")
+def get_sql_username(raise_if_empty: bool = False) -> str:
+    get_sql_username_result = our_get_env("RDS_USERNAME",
+                                          raise_if_empty=raise_if_empty)
     return get_sql_username_result
 
 
-def get_sql_password() -> str:
-    get_sql_password_result = our_get_env("RDS_PASSWORD")
+def get_sql_password(raise_if_empty: bool = False) -> str:
+    get_sql_password_result = our_get_env("RDS_PASSWORD",
+                                          raise_if_empty=raise_if_empty)
     return get_sql_password_result
 
 
@@ -445,8 +458,10 @@ def camel_to_snake(camel_str: str) -> str:
     return snake_str
 
 
+# We have both deprecation_warning as method in Logger and as a standalone function
+# We can call the deprecation_warning_function from the logger
 @lru_cache(maxsize=64)  # don't print the same warning multiple times
-def deprecation_warning(old_name: str, new_name: str, start_date: date = None) -> None:
+def deprecation_warning_function(old_name: str, new_name: str, start_date: date = None) -> None:
     if start_date and start_date < date.today():
         return
     warnings_message = f"Please use {old_name} instead of {new_name}."
